import React, { ComponentType } from 'react';
import { ViewProps, ViewStyle, StyleProp, TextStyle } from 'react-native';
import { $DeepPartial } from '@callstack/react-theme-provider';
import { WrapIconProps } from '../icon-wrapper';
export declare type ChannelValueProps = ViewProps & {
    /** Text to display for the value (bold text) */
    value: string | number;
    /** A component to render for the icon */
    IconClass?: ComponentType<WrapIconProps>;
    /**
     * Props to spread to the icon component
     *
     * @deprecated in version 6.0.0
     */
    IconProps?: {
        size?: number;
        color?: string;
    };
    /**
     * The size of the icon
     *
     * Default: fontSize
     */
    iconSize?: number;
    /**
     * The color of the primary icon
     *
     * Default: Theme.colors.text
     */
    iconColor?: string;
    /** Text to display for the units (light text) */
    units?: string;
    /** Whether to show the units before the value (e.g., for currency)
     *
     * Default: false
     */
    prefix?: boolean;
    /** The size to use for the text elements
     *
     * Default: 16
     */
    fontSize?: number;
    /** The color used for the text elements */
    color?: string;
    /** Style overrides for internal elements. The styles you provide will be combined with the default styles. */
    styles?: {
        root?: StyleProp<ViewStyle>;
        value?: StyleProp<TextStyle>;
        units?: StyleProp<TextStyle>;
    };
    /**
     * Theme value overrides specific to this component.
     */
    theme?: $DeepPartial<ReactNativePaper.Theme>;
};
/**
 * [ChannelValue](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--channel-value) component
 *
 * Used to show a stylized value and its units.
 * You may also include an icon.
 */
export declare const ChannelValue: React.FC<ChannelValueProps>;
