import React, { ComponentType } from 'react';
import { StyleProp, ViewStyle, TextStyle, ViewProps } from 'react-native';
import { $DeepPartial } from '@callstack/react-theme-provider';
import { WrapIconProps } from '../icon-wrapper';
export declare type EmptyStateProps = ViewProps & {
    /** The primary text to display (first line) */
    title: string;
    /** The secondary text to display (second line) */
    description?: string;
    /** A component to render for the primary icon
     *
     * @deprecated in version 6.0.0
     */
    IconClass?: ComponentType<WrapIconProps>;
    /** A component to render for the primary icon */
    icon?: ComponentType<WrapIconProps>;
    /**
     * Props to spread to the primary icon component
     *
     * @deprecated in version 6.0.0
     */
    IconProps?: {
        size?: number;
        color?: string;
    };
    /** The size of the primary icon (100-200) */
    iconSize?: number;
    /** The color of the primary icon */
    iconColor?: string;
    /** Additional components to render below the text (e.g., action buttons) */
    actions?: JSX.Element;
    /** Style overrides for internal elements. The styles you provide will be combined with the default styles. */
    styles?: {
        root?: StyleProp<ViewStyle>;
        title?: StyleProp<TextStyle>;
        description?: StyleProp<TextStyle>;
        actions?: StyleProp<ViewStyle>;
    };
    /**
     * Theme value overrides specific to this component.
     */
    theme?: $DeepPartial<ReactNativePaper.Theme>;
};
/**
 * [EmptyState](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--empty-state) component
 *
 * Used as a placeholder when no content is available for a particular area/screen in your application.
 * It displays an icon with up to two lines of text and has an area for you to add custom actionable content or
 * calls-to-action.
 */
export declare const EmptyState: React.FC<EmptyStateProps>;
