"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hero = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const channel_value_1 = require("../channel-value");
const react_native_paper_1 = require("react-native-paper");
const typography_1 = require("../typography");
const makeStyles = (fontScale) => react_native_1.StyleSheet.create({
    root: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
        paddingHorizontal: 8,
        paddingVertical: 16,
    },
    iconWrapper: {
        padding: 0,
        marginBottom: 4 * fontScale,
        alignItems: 'center',
        justifyContent: 'center',
        overflow: 'hidden',
        height: 48 * fontScale,
        width: 48 * fontScale,
        borderRadius: 24 * fontScale,
    },
    values: {
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        maxWidth: '100%',
    },
    label: {
        width: '100%',
        overflow: 'hidden',
        textAlign: 'center',
    },
});
/**
 * [Hero](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--hero) component
 *
 * The Hero is used to call attention to particular values of importance to the user. It includes a
 * large icon with a label and (typically) a [ChannelValue](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--channel-value) item. The channel value can be configured
 * through the `value` and `units` props, or passed declaratively as a child.
 */
exports.Hero = (props) => {
    const { label, value, ValueIconClass, valueIcon: valueIconProp, valueColor, fontSize = 20, units, onPress, IconClass, icon: iconProp, iconColor, iconSize, iconBackgroundColor, children, styles = {}, style, theme: themeOverride, ...viewProps } = props;
    // Compatibility to facilitate updates
    const Icon = iconProp || IconClass;
    const valueIcon = valueIconProp || ValueIconClass;
    const ChannelProps = props.ChannelValueProps || {
        IconClass: props.valueIcon,
        value: props.value || '',
        units: props.units,
        color: props.valueColor,
        fontSize: props.fontSize,
    };
    // Deprecation Warning
    react_1.useEffect(() => {
        if (IconClass) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'IconClass' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the renamed 'icon' prop instead.`);
        }
    }, [IconClass]);
    react_1.useEffect(() => {
        if (ValueIconClass) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'ValueIconClass' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the renamed 'valueIcon' prop instead.`);
        }
    }, [ValueIconClass]);
    react_1.useEffect(() => {
        if (fontSize) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'fontSize' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the 'channelValueProps' prop instead.`);
        }
    }, [fontSize]);
    react_1.useEffect(() => {
        if (value) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'value' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the 'channelValueProps' prop instead.`);
        }
    }, [value]);
    react_1.useEffect(() => {
        if (valueIcon) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'valueIcon' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the 'channelValueProps' prop instead.`);
        }
    }, [valueIcon]);
    react_1.useEffect(() => {
        if (valueColor) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'valueColor' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the 'channelValueProps' prop instead.`);
        }
    }, [valueColor]);
    react_1.useEffect(() => {
        if (units) {
            // eslint-disable-next-line no-console
            console.warn(`Property 'units' in Hero component has been deprecated and will be removed in version 6.0.0. You should update to use the 'channelValueProps' prop instead.`);
        }
    }, [units]);
    const theme = react_native_paper_1.useTheme(themeOverride);
    const fontScale = react_native_1.PixelRatio.getFontScale();
    const defaultStyles = makeStyles(fontScale);
    const normalizeIconSize = react_1.useCallback(() => {
        if (!iconSize)
            return 36;
        return Math.max(10, Math.min(48, iconSize));
    }, [iconSize]);
    const getColor = react_1.useCallback((color) => {
        if (!color)
            return theme.colors.text;
        if (Object.keys(theme.colors).indexOf(color) >= 0)
            return theme.colors[color];
        return color;
    }, [theme]);
    const getIcon = react_1.useCallback(() => {
        if (Icon) {
            return react_1.default.createElement(Icon, { size: normalizeIconSize(), color: getColor(iconColor) });
        }
    }, [Icon, normalizeIconSize, getColor, iconColor]);
    return (react_1.default.createElement(react_native_1.TouchableOpacity, Object.assign({ onPress: onPress, disabled: !onPress, style: [defaultStyles.root, styles.root, style] }, viewProps),
        react_1.default.createElement(react_native_1.View, { style: [
                defaultStyles.iconWrapper,
                { backgroundColor: iconBackgroundColor || theme.colors.surface },
                styles.iconWrapper,
            ] }, getIcon()),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.values, styles.values] },
            !children && (!!value || props.ChannelValueProps) && react_1.default.createElement(channel_value_1.ChannelValue, Object.assign({}, ChannelProps)),
            children),
        react_1.default.createElement(typography_1.Body1, { style: [defaultStyles.label, styles.label], numberOfLines: 1, ellipsizeMode: 'tail' }, label)));
};
